@@ -57,10 +57,10 @@ pub use PyString as PyUnicode;
 #[cfg(feature = "python27-sys")]
 impl crate::python::PythonObjectWithCheckedDowncast for PyString {
     #[inline]
-    fn downcast_from<'p>(
-        py: Python<'p>,
+    fn downcast_from(
+        py: Python<'_>,
         obj: PyObject,
-    ) -> Result<PyString, PythonObjectDowncastError<'p>> {
+    ) -> Result<PyString, PythonObjectDowncastError<'_>> {
         if is_base_string(&obj) {
             Ok(PyString(obj))
         } else {
@@ -159,7 +159,7 @@ impl<'a> PyStringData<'a> {
                 )),
             },
             PyStringData::Latin1(data) => {
-                if data.iter().all(|&b| b.is_ascii()) {
+                if data.is_ascii() {
                     Ok(Cow::Borrowed(unsafe { str::from_utf8_unchecked(data) }))
                 } else {
                     Ok(Cow::Owned(data.iter().map(|&b| b as char).collect()))
@@ -214,7 +214,7 @@ impl<'a> PyStringData<'a> {
         match self {
             PyStringData::Utf8(data) => String::from_utf8_lossy(data),
             PyStringData::Latin1(data) => {
-                if data.iter().all(|&b| b.is_ascii()) {
+                if data.is_ascii() {
                     Cow::Borrowed(unsafe { str::from_utf8_unchecked(data) })
                 } else {
                     Cow::Owned(data.iter().map(|&b| b as char).collect())
@@ -283,17 +283,30 @@ impl PyString {
     }
 
     #[cfg(feature = "python3-sys")]
-    fn data_impl(&self, py: Python) -> PyStringData {
-        // TODO: return the original representation instead
-        // of forcing the UTF-8 representation to be created.
-        let mut size: ffi::Py_ssize_t = 0;
+    fn data_impl(&self, _py: Python) -> PyStringData {
+        let ptr = self.as_ptr();
         unsafe {
-            let data = ffi::PyUnicode_AsUTF8AndSize(self.as_ptr(), &mut size) as *const u8;
-            if data.is_null() {
-                PyErr::fetch(py).print(py);
-                panic!("PyUnicode_AsUTF8AndSize failed");
+            let ready = ffi::PyUnicode_READY(ptr);
+            if ready < 0 {
+                // should fail only on OOM
+                ffi::PyErr_Print();
+                panic!("PyUnicode_READY failed");
+            }
+            let size = ffi::PyUnicode_GET_LENGTH(ptr) as usize;
+            let data = ffi::PyUnicode_DATA(ptr);
+            let kind = ffi::PyUnicode_KIND(ptr);
+            match kind {
+                ffi::PyUnicode_1BYTE_KIND => {
+                    PyStringData::Latin1(std::slice::from_raw_parts(data as *const u8, size))
+                }
+                ffi::PyUnicode_2BYTE_KIND => {
+                    PyStringData::Utf16(std::slice::from_raw_parts(data as *const u16, size))
+                }
+                ffi::PyUnicode_4BYTE_KIND => {
+                    PyStringData::Utf32(std::slice::from_raw_parts(data as *const u32, size))
+                }
+                _ => panic!("Unknown PyUnicode_KIND"),
             }
-            PyStringData::Utf8(std::slice::from_raw_parts(data, size as usize))
         }
     }
 
@@ -306,7 +319,26 @@ impl PyString {
     /// (containing unpaired surrogates, or a Python 2.7 byte string that is
     /// not valid UTF-8).
     pub fn to_string(&self, py: Python) -> PyResult<Cow<str>> {
-        self.data(py).to_string(py)
+        #[cfg(feature = "python3-sys")]
+        unsafe {
+            // On Python 3, we can use the UTF-8 representation stored
+            // inside the Python string.
+            // This should produce identical results to
+            // `self.data(py).to_string(py)` but avoids
+            // re-encoding the string on every to_string call.
+            let mut size: ffi::Py_ssize_t = 0;
+            let data = ffi::PyUnicode_AsUTF8AndSize(self.as_ptr(), &mut size);
+            if data.is_null() {
+                Err(PyErr::fetch(py))
+            } else {
+                let slice = std::slice::from_raw_parts(data as *const u8, size as usize);
+                Ok(Cow::Borrowed(std::str::from_utf8_unchecked(slice)))
+            }
+        }
+        #[cfg(feature = "python27-sys")]
+        {
+            self.data(py).to_string(py)
+        }
     }
 
     /// Convert the `PyString` into a Rust string.
@@ -533,6 +565,7 @@ impl RefFromPyObject for [u8] {
 
 #[cfg(test)]
 mod test {
+    use super::{PyString, PyStringData};
     use crate::conversion::{RefFromPyObject, ToPyObject};
     use crate::python::{Python, PythonObject};
 
@@ -583,4 +616,52 @@ mod test {
         let v = py_bytes.extract::<Vec<u8>>(py).unwrap();
         assert_eq!(b"Hello", &v[..]);
     }
+
+    #[allow(unused_variables)] // when compiling for py2.7
+    #[test]
+    fn test_extract_umlaut() {
+        let gil = Python::acquire_gil();
+        let py = gil.python();
+        let py_string = py.eval("u'x=\\u00e4'", None, None).unwrap();
+        let data = py_string.cast_as::<PyString>(py).unwrap().data(py);
+        #[cfg(feature = "python3-sys")]
+        {
+            if let PyStringData::Latin1(s) = data {
+                assert_eq!([b'x', b'=', 0xe4], *s);
+            } else {
+                panic!("Expected PyStringData::Latin1");
+            }
+        }
+        assert_eq!("x=ä", py_string.extract::<String>(py).unwrap());
+    }
+
+    #[allow(unused_variables)] // when compiling for py2.7
+    #[test]
+    fn test_extract_lone_surrogate() {
+        let gil = Python::acquire_gil();
+        let py = gil.python();
+        let py_string = py.eval("u'x=\\ud800'", None, None).unwrap();
+        let data = py_string.cast_as::<PyString>(py).unwrap().data(py);
+        #[cfg(feature = "python3-sys")]
+        {
+            if let PyStringData::Utf16(s) = data {
+                assert_eq!(['x' as u16, '=' as u16, 0xd800], *s);
+            } else {
+                panic!("Expected PyStringData::Utf16");
+            }
+        }
+        assert!(py_string.extract::<String>(py).is_err());
+    }
+
+    #[test]
+    fn test_extract_lone_surrogate_lossy() {
+        let gil = Python::acquire_gil();
+        let py = gil.python();
+        let py_string = py.eval("u'x=\\ud800'", None, None).unwrap();
+        let result = py_string
+            .cast_as::<PyString>(py)
+            .unwrap()
+            .to_string_lossy(py);
+        assert_eq!("x=\u{fffd}", result);
+    }
 }
